v1beta1

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 18, 2020 License: UPL-1.0 Imports: 7 Imported by: 0

Documentation

Overview

This package has the automatically generated typed clients.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type HelidonAppExpansion

type HelidonAppExpansion interface{}

type HelidonAppInterface

type HelidonAppInterface interface {
	Create(*v1beta1.HelidonApp) (*v1beta1.HelidonApp, error)
	Update(*v1beta1.HelidonApp) (*v1beta1.HelidonApp, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1beta1.HelidonApp, error)
	List(opts v1.ListOptions) (*v1beta1.HelidonAppList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.HelidonApp, err error)
	HelidonAppExpansion
}

HelidonAppInterface has methods to work with HelidonApp resources.

type HelidonAppsGetter

type HelidonAppsGetter interface {
	HelidonApps(namespace string) HelidonAppInterface
}

HelidonAppsGetter has a method to return a HelidonAppInterface. A group's client should implement this interface.

type VerrazzanoV1beta1Client

type VerrazzanoV1beta1Client struct {
	// contains filtered or unexported fields
}

VerrazzanoV1beta1Client is used to interact with features provided by the verrazzano.io group.

func New

New creates a new VerrazzanoV1beta1Client for the given RESTClient.

func NewForConfig

func NewForConfig(c *rest.Config) (*VerrazzanoV1beta1Client, error)

NewForConfig creates a new VerrazzanoV1beta1Client for the given config.

func NewForConfigOrDie

func NewForConfigOrDie(c *rest.Config) *VerrazzanoV1beta1Client

NewForConfigOrDie creates a new VerrazzanoV1beta1Client for the given config and panics if there is an error in the config.

func (*VerrazzanoV1beta1Client) HelidonApps

func (c *VerrazzanoV1beta1Client) HelidonApps(namespace string) HelidonAppInterface

func (*VerrazzanoV1beta1Client) RESTClient

func (c *VerrazzanoV1beta1Client) RESTClient() rest.Interface

RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.

type VerrazzanoV1beta1Interface

type VerrazzanoV1beta1Interface interface {
	RESTClient() rest.Interface
	HelidonAppsGetter
}

Directories

Path Synopsis
Package fake has the automatically generated clients.
Package fake has the automatically generated clients.

Jump to